@@ -1,17 +1,17 @@
 #ifndef OBGTK_DIALOG_H
 #define OBGTK_DIALOG_H 1
-
+#include <obgtk/obgtkWidget.h>
 #include <obgtk/obgtkWindow.h>
-#include <gtk/gtk.h>
+#include <gtk/gtkdialog.h>
 
-@class Gtk_HBox, Gtk_VBox;
 @interface Gtk_Dialog : Gtk_Window
 {
 @public
   GtkDialog *gtkdialog;
-  id vbox, action_area; 
 }
-- castGtkDialog:(GtkDialog *)castitem;
+- castGtkDialog : (GtkDialog *) castitem;
++ (id)makeGtkDialog : (GtkDialog *) castitem;
+- init;
 @end
 
-#endif /* OBGTK_DIALOG_H */
+#endif /* OBGTK_DIALOG_H */
\ No newline at end of file
