@@ -1,10 +1,17 @@
 #ifndef OBGTK_HPANED_H
 #define OBGTK_HPANED_H 1
+#include <obgtk/obgtkWidget.h>
 #include <obgtk/obgtkPaned.h>
 #include <gtk/gtkhpaned.h>
 
 @interface Gtk_HPaned : Gtk_Paned
+{
+@public
+  GtkHPaned *gtkhpaned;
+}
+- castGtkHPaned : (GtkHPaned *) castitem;
++ (id)makeGtkHPaned : (GtkHPaned *) castitem;
 - init;
-- castGtkHPaned:(GtkHPaned *)castitem;
 @end
-#endif /* OBGTK_HPANED_H */
+
+#endif /* OBGTK_HPANED_H */
\ No newline at end of file
