@@ -1,10 +1,17 @@
 #ifndef OBGTK_VPANED_H
 #define OBGTK_VPANED_H 1
-
+#include <obgtk/obgtkWidget.h>
 #include <obgtk/obgtkPaned.h>
 #include <gtk/gtkvpaned.h>
 
 @interface Gtk_VPaned : Gtk_Paned
-- castGtkVPaned:(GtkVPaned *)castitem;
+{
+@public
+  GtkVPaned *gtkvpaned;
+}
+- castGtkVPaned : (GtkVPaned *) castitem;
++ (id)makeGtkVPaned : (GtkVPaned *) castitem;
+- init;
 @end
-#endif /* OBGTK_VPANED_H */
+
+#endif /* OBGTK_VPANED_H */
\ No newline at end of file
