@@ -1,12 +1,19 @@
 #ifndef OBGTK_VSCALE_H
 #define OBGTK_VSCALE_H 1
-
-#include <obgtk/obgtkScale.h>
+#include <obgtk/obgtkWidget.h>
 #include <obgtk/obgtkAdjustment.h>
+#include <obgtk/obgtkScale.h>
 #include <gtk/gtkvscale.h>
 
 @interface Gtk_VScale : Gtk_Scale
-- initWithGtkAdjustment:(id) adjustment;
+{
+@public
+  GtkVScale *gtkvscale;
+}
+- castGtkVScale : (GtkVScale *) castitem;
++ (id)makeGtkVScale : (GtkVScale *) castitem;
+- initWithVScaleInfo
+ : (id) adjustment;
 @end
 
-#endif /* OBGTK_VSCALE_H */
+#endif /* OBGTK_VSCALE_H */
\ No newline at end of file
